#include <Arduino.h>
#include <ESP8266WiFi.h>
#include <ESP8266WiFiMulti.h>
#include <ESP8266HTTPClient.h>
#include <WiFiClient.h>

#include "Adafruit_WS2801.h"
#include "SPI.h" // Comment out this line if using Trinket or Gemma

uint8_t dataPin  = 12;    // Yellow wire on Adafruit Pixels
uint8_t clockPin = 14;    // Green wire on Adafruit Pixels

// Set the first variable to the NUMBER of pixels. 20 = 20 pixels in a row
Adafruit_WS2801 strip = Adafruit_WS2801(20, dataPin, clockPin);

ESP8266WiFiMulti WiFiMulti;
int leds[30]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0}; //receiving 30 fields, really needing only 20, but we could use the extra bits for expanding functionality

void setup() {

  Serial.begin(115200);
  // Serial.setDebugOutput(true);

  Serial.println();
  Serial.println();
  Serial.println();
  
  strip.begin();
  strip.show();
  
  for (uint8_t t = 4; t > 0; t--) {
    Serial.printf("[SETUP] WAIT %d...\n", t);
    Serial.flush();
    delay(1000);
  }

  WiFi.mode(WIFI_STA);
  WiFiMulti.addAP("YOUR_WIFI_ID", "YOUR_WIFI_PASSWORD"); //Insert your wifi name and password here

}


void loop() {
  // wait for WiFi connection
  if ((WiFiMulti.run() == WL_CONNECTED)) {

    WiFiClient client;

    HTTPClient http;

    const char s[2] = ",";
    char *token;
    
    //Serial.print("[HTTP] begin...\n");
    if (http.begin(client, "http://165.13.45.123:3000/api")) {  //  //YOUR WEBSITE ADDRESS HERE

      //Serial.print("[HTTP] GET...\n");
      // start connection and send HTTP header
      int httpCode = http.GET();

      // httpCode will be negative on error
      if (httpCode > 0) {
        // HTTP header has been send and Server response header has been handled
        //Serial.printf("[HTTP] GET... code: %d\n", httpCode);

        // file found at server
        if (httpCode == HTTP_CODE_OK || httpCode == HTTP_CODE_MOVED_PERMANENTLY) {
          char* payload = (char*)http.getString().c_str();
          //Serial.println(payload);
          
          token = strtok(payload, s);
   
           /* walk through other tokens */
           int i=0;
           while( token != NULL ) {
              sscanf(token, "%d", &leds[i]); // Using sscanf
              i++;
              token = strtok(NULL, s);
           }
           /*for(i=0;i<20;i++)
           {
                printf( " %d\n", leds[i] );
           }*/
           led_gpio_handling();
        }
      } else {
        Serial.printf("[HTTP] GET... failed, error: %s\n", http.errorToString(httpCode).c_str());
      }

      http.end();
    } else {
      Serial.printf("[HTTP} Unable to connect\n");
    }
  }
  
    /*
   * LED STATES:
   * 0-off
   * 1-red
   * 2-orange
   * 3-yellow
   * 4-green
   * 5-blue
   * 6-white
   * 7-off
   */
  for(uint i=0;i<20;i++)
  {
    if(leds[i] == 0){
     strip.setPixelColor(i,0,0,0); //off
    }
    if(leds[i] == 1){
      strip.setPixelColor(i,255,0,0); //Red
    }
    if(leds[i] == 2){
      strip.setPixelColor(i,255,70,0); //orange   
    }
    if(leds[i] == 3){
      strip.setPixelColor(i,255,220,0); //yellow    
    }
    if(leds[i] == 4){
      strip.setPixelColor(i,0,255,0); //green
    }
    if(leds[i] == 5){
      strip.setPixelColor(i,0,0,255); //blue
    }
    if(leds[i] == 6){
      strip.setPixelColor(i,255,255,255); //white
    } 
    if(leds[i] == 7){
     strip.setPixelColor(i,0,0,0); //off
    }
  }
  
  strip.show();
  
  delay(200);
}
